==> servicecatalog-model-6.3.0-sources.jar: io/fabric8/servicecatalog/api/model/ClusterServiceBrokerListFluentImpl.java <==
package io.fabric8.servicecatalog.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ClusterServiceBrokerListFluentImpl<A extends ClusterServiceBrokerListFluent<A>> extends BaseFluent<A> implements ClusterServiceBrokerListFluent<A>{
  public ClusterServiceBrokerListFluentImpl() {
  }
  public ClusterServiceBrokerListFluentImpl(ClusterServiceBrokerList instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withItems(instance.getItems()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
  }
  private String apiVersion;
  private ArrayList<ClusterServiceBrokerBuilder> items = new ArrayList<ClusterServiceBrokerBuilder>();
  private String kind;
  private ListMeta metadata;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public A addToItems(Integer index,ClusterServiceBroker item) {
    if (this.items == null) {this.items = new ArrayList<ClusterServiceBrokerBuilder>();}
    ClusterServiceBrokerBuilder builder = new ClusterServiceBrokerBuilder(item);_visitables.get("items").add(index >= 0 ? index : _visitables.get("items").size(), builder);this.items.add(index >= 0 ? index : items.size(), builder); return (A)this;
  }
  public A setToItems(Integer index,ClusterServiceBroker item) {
    if (this.items == null) {this.items = new ArrayList<ClusterServiceBrokerBuilder>();}
    ClusterServiceBrokerBuilder builder = new ClusterServiceBrokerBuilder(item);
    if (index < 0 || index >= _visitables.get("items").size()) { _visitables.get("items").add(builder); } else { _visitables.get("items").set(index, builder);}
    if (index < 0 || index >= items.size()) { items.add(builder); } else { items.set(index, builder);}
     return (A)this;
  }
  public A addToItems(io.fabric8.servicecatalog.api.model.ClusterServiceBroker... items) {
    if (this.items == null) {this.items = new ArrayList<ClusterServiceBrokerBuilder>();}
    for (ClusterServiceBroker item : items) {ClusterServiceBrokerBuilder builder = new ClusterServiceBrokerBuilder(item);_visitables.get("items").add(builder);this.items.add(builder);} return (A)this;
  }
  public A addAllToItems(Collection<ClusterServiceBroker> items) {
    if (this.items == null) {this.items = new ArrayList<ClusterServiceBrokerBuilder>();}
    for (ClusterServiceBroker item : items) {ClusterServiceBrokerBuilder builder = new ClusterServiceBrokerBuilder(item);_visitables.get("items").add(builder);this.items.add(builder);} return (A)this;
  }
  public A removeFromItems(io.fabric8.servicecatalog.api.model.ClusterServiceBroker... items) {
    for (ClusterServiceBroker item : items) {ClusterServiceBrokerBuilder builder = new ClusterServiceBrokerBuilder(item);_visitables.get("items").remove(builder);if (this.items != null) {this.items.remove(builder);}} return (A)this;
  }
  public A removeAllFromItems(Collection<ClusterServiceBroker> items) {
    for (ClusterServiceBroker item : items) {ClusterServiceBrokerBuilder builder = new ClusterServiceBrokerBuilder(item);_visitables.get("items").remove(builder);if (this.items != null) {this.items.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromItems(Predicate<ClusterServiceBrokerBuilder> predicate) {
    if (items == null) return (A) this;
    final Iterator<ClusterServiceBrokerBuilder> each = items.iterator();
    final List visitables = _visitables.get("items");
    while (each.hasNext()) {
      ClusterServiceBrokerBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ClusterServiceBroker> getItems() {
    return items != null ? build(items) : null;
  }
  public List<ClusterServiceBroker> buildItems() {
    return items != null ? build(items) : null;
  }
  public ClusterServiceBroker buildItem(Integer index) {
    return this.items.get(index).build();
  }
  public ClusterServiceBroker buildFirstItem() {
    return this.items.get(0).build();
  }
  public ClusterServiceBroker buildLastItem() {
    return this.items.get(items.size() - 1).build();
  }
  public ClusterServiceBroker buildMatchingItem(Predicate<ClusterServiceBrokerBuilder> predicate) {
    for (ClusterServiceBrokerBuilder item: items) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public Boolean hasMatchingItem(Predicate<ClusterServiceBrokerBuilder> predicate) {
    for (ClusterServiceBrokerBuilder item: items) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withItems(List<ClusterServiceBroker> items) {
    if (this.items != null) { _visitables.get("items").removeAll(this.items);}
    if (items != null) {this.items = new ArrayList(); for (ClusterServiceBroker item : items){this.addToItems(item);}} else { this.items = null;} return (A) this;
  }
  public A withItems(io.fabric8.servicecatalog.api.model.ClusterServiceBroker... items) {
    if (this.items != null) {this.items.clear();}
    if (items != null) {for (ClusterServiceBroker item :items){ this.addToItems(item);}} return (A) this;
  }
  public Boolean hasItems() {
    return items != null && !items.isEmpty();
  }
  public ClusterServiceBrokerListFluent.ItemsNested<A> addNewItem() {
    return new ClusterServiceBrokerListFluentImpl.ItemsNestedImpl();
  }
  public ClusterServiceBrokerListFluent.ItemsNested<A> addNewItemLike(ClusterServiceBroker item) {
    return new ClusterServiceBrokerListFluentImpl.ItemsNestedImpl(-1, item);
  }
  public ClusterServiceBrokerListFluent.ItemsNested<A> setNewItemLike(Integer index,ClusterServiceBroker item) {
    return new ClusterServiceBrokerListFluentImpl.ItemsNestedImpl(index, item);
  }
  public ClusterServiceBrokerListFluent.ItemsNested<A> editItem(Integer index) {
    if (items.size() <= index) throw new RuntimeException("Can't edit items. Index exceeds size.");
    return setNewItemLike(index, buildItem(index));
  }
  public ClusterServiceBrokerListFluent.ItemsNested<A> editFirstItem() {
    if (items.size() == 0) throw new RuntimeException("Can't edit first items. The list is empty.");
    return setNewItemLike(0, buildItem(0));
  }
  public ClusterServiceBrokerListFluent.ItemsNested<A> editLastItem() {
    int index = items.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last items. The list is empty.");
    return setNewItemLike(index, buildItem(index));
  }
  public ClusterServiceBrokerListFluent.ItemsNested<A> editMatchingItem(Predicate<ClusterServiceBrokerBuilder> predicate) {
    int index = -1;
    for (int i=0;i<items.size();i++) { 
    if (predicate.test(items.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching items. No match found.");
    return setNewItemLike(index, buildItem(index));
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  public ListMeta getMetadata() {
    return this.metadata;
  }
  public A withMetadata(ListMeta metadata) {
    this.metadata=metadata; return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink) {
    return (A)withMetadata(new ListMeta(_continue, remainingItemCount, resourceVersion, selfLink));
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ClusterServiceBrokerListFluentImpl that = (ClusterServiceBrokerListFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (items != null ? !items.equals(that.items) :that.items != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  items,  kind,  metadata,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (items != null && !items.isEmpty()) { sb.append("items:"); sb.append(items + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata); }
    sb.append("}");
    return sb.toString();
  }
  class ItemsNestedImpl<N> extends ClusterServiceBrokerFluentImpl<ClusterServiceBrokerListFluent.ItemsNested<N>> implements ClusterServiceBrokerListFluent.ItemsNested<N>,Nested<N>{
    ItemsNestedImpl(Integer index,ClusterServiceBroker item) {
      this.index = index;
      this.builder = new ClusterServiceBrokerBuilder(this, item);
    }
    ItemsNestedImpl() {
      this.index = -1;
      this.builder = new ClusterServiceBrokerBuilder(this);
    }
    ClusterServiceBrokerBuilder builder;
    Integer index;
    public N and() {
      return (N) ClusterServiceBrokerListFluentImpl.this.setToItems(index,builder.build());
    }
    public N endItem() {
      return and();
    }
    
  }
  
}

==> servicecatalog-model-6.7.2-sources.jar: io/fabric8/servicecatalog/api/model/ClusterServiceBrokerListFluentImpl.java <==
package io.fabric8.servicecatalog.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ClusterServiceBrokerListFluentImpl<A extends ClusterServiceBrokerListFluent<A>> extends BaseFluent<A> implements ClusterServiceBrokerListFluent<A>{
  public ClusterServiceBrokerListFluentImpl() {
  }
  public ClusterServiceBrokerListFluentImpl(ClusterServiceBrokerList instance) {
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withItems(instance.getItems());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
    }
  }
  private String apiVersion;
  private ArrayList<ClusterServiceBrokerBuilder> items = new ArrayList<ClusterServiceBrokerBuilder>();
  private String kind;
  private ListMeta metadata;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public A addToItems(int index,ClusterServiceBroker item) {
    if (this.items == null) {this.items = new ArrayList<ClusterServiceBrokerBuilder>();}
    ClusterServiceBrokerBuilder builder = new ClusterServiceBrokerBuilder(item);
    if (index < 0 || index >= items.size()) { _visitables.get("items").add(builder); items.add(builder); } else { _visitables.get("items").add(index, builder); items.add(index, builder);}
    return (A)this;
  }
  public A setToItems(int index,ClusterServiceBroker item) {
    if (this.items == null) {this.items = new ArrayList<ClusterServiceBrokerBuilder>();}
    ClusterServiceBrokerBuilder builder = new ClusterServiceBrokerBuilder(item);
    if (index < 0 || index >= items.size()) { _visitables.get("items").add(builder); items.add(builder); } else { _visitables.get("items").set(index, builder); items.set(index, builder);}
    return (A)this;
  }
  public A addToItems(io.fabric8.servicecatalog.api.model.ClusterServiceBroker... items) {
    if (this.items == null) {this.items = new ArrayList<ClusterServiceBrokerBuilder>();}
    for (ClusterServiceBroker item : items) {ClusterServiceBrokerBuilder builder = new ClusterServiceBrokerBuilder(item);_visitables.get("items").add(builder);this.items.add(builder);} return (A)this;
  }
  public A addAllToItems(Collection<ClusterServiceBroker> items) {
    if (this.items == null) {this.items = new ArrayList<ClusterServiceBrokerBuilder>();}
    for (ClusterServiceBroker item : items) {ClusterServiceBrokerBuilder builder = new ClusterServiceBrokerBuilder(item);_visitables.get("items").add(builder);this.items.add(builder);} return (A)this;
  }
  public A removeFromItems(io.fabric8.servicecatalog.api.model.ClusterServiceBroker... items) {
    for (ClusterServiceBroker item : items) {ClusterServiceBrokerBuilder builder = new ClusterServiceBrokerBuilder(item);_visitables.get("items").remove(builder);if (this.items != null) {this.items.remove(builder);}} return (A)this;
  }
  public A removeAllFromItems(Collection<ClusterServiceBroker> items) {
    for (ClusterServiceBroker item : items) {ClusterServiceBrokerBuilder builder = new ClusterServiceBrokerBuilder(item);_visitables.get("items").remove(builder);if (this.items != null) {this.items.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromItems(Predicate<ClusterServiceBrokerBuilder> predicate) {
    if (items == null) return (A) this;
    final Iterator<ClusterServiceBrokerBuilder> each = items.iterator();
    final List visitables = _visitables.get("items");
    while (each.hasNext()) {
      ClusterServiceBrokerBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ClusterServiceBroker> getItems() {
    return items != null ? build(items) : null;
  }
  public List<ClusterServiceBroker> buildItems() {
    return items != null ? build(items) : null;
  }
  public ClusterServiceBroker buildItem(int index) {
    return this.items.get(index).build();
  }
  public ClusterServiceBroker buildFirstItem() {
    return this.items.get(0).build();
  }
  public ClusterServiceBroker buildLastItem() {
    return this.items.get(items.size() - 1).build();
  }
  public ClusterServiceBroker buildMatchingItem(Predicate<ClusterServiceBrokerBuilder> predicate) {
    for (ClusterServiceBrokerBuilder item: items) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public Boolean hasMatchingItem(Predicate<ClusterServiceBrokerBuilder> predicate) {
    for (ClusterServiceBrokerBuilder item: items) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withItems(List<ClusterServiceBroker> items) {
    if (this.items != null) { _visitables.get("items").clear();}
    if (items != null) {this.items = new ArrayList(); for (ClusterServiceBroker item : items){this.addToItems(item);}} else { this.items = null;} return (A) this;
  }
  public A withItems(io.fabric8.servicecatalog.api.model.ClusterServiceBroker... items) {
    if (this.items != null) {this.items.clear(); _visitables.remove("items"); }
    if (items != null) {for (ClusterServiceBroker item :items){ this.addToItems(item);}} return (A) this;
  }
  public Boolean hasItems() {
    return items != null && !items.isEmpty();
  }
  public ClusterServiceBrokerListFluentImpl.ItemsNested<A> addNewItem() {
    return new ClusterServiceBrokerListFluentImpl.ItemsNestedImpl();
  }
  public ClusterServiceBrokerListFluentImpl.ItemsNested<A> addNewItemLike(ClusterServiceBroker item) {
    return new ClusterServiceBrokerListFluentImpl.ItemsNestedImpl(-1, item);
  }
  public ClusterServiceBrokerListFluentImpl.ItemsNested<A> setNewItemLike(int index,ClusterServiceBroker item) {
    return new ClusterServiceBrokerListFluentImpl.ItemsNestedImpl(index, item);
  }
  public ClusterServiceBrokerListFluentImpl.ItemsNested<A> editItem(int index) {
    if (items.size() <= index) throw new RuntimeException("Can't edit items. Index exceeds size.");
    return setNewItemLike(index, buildItem(index));
  }
  public ClusterServiceBrokerListFluentImpl.ItemsNested<A> editFirstItem() {
    if (items.size() == 0) throw new RuntimeException("Can't edit first items. The list is empty.");
    return setNewItemLike(0, buildItem(0));
  }
  public ClusterServiceBrokerListFluentImpl.ItemsNested<A> editLastItem() {
    int index = items.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last items. The list is empty.");
    return setNewItemLike(index, buildItem(index));
  }
  public ClusterServiceBrokerListFluentImpl.ItemsNested<A> editMatchingItem(Predicate<ClusterServiceBrokerBuilder> predicate) {
    int index = -1;
    for (int i=0;i<items.size();i++) { 
    if (predicate.test(items.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching items. No match found.");
    return setNewItemLike(index, buildItem(index));
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  public ListMeta getMetadata() {
    return this.metadata;
  }
  public A withMetadata(ListMeta metadata) {
    this.metadata=metadata; return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink) {
    return (A)withMetadata(new ListMeta(_continue, remainingItemCount, resourceVersion, selfLink));
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ClusterServiceBrokerListFluentImpl that = (ClusterServiceBrokerListFluentImpl) o;
    if (!java.util.Objects.equals(apiVersion, that.apiVersion)) return false;

    if (!java.util.Objects.equals(items, that.items)) return false;

    if (!java.util.Objects.equals(kind, that.kind)) return false;

    if (!java.util.Objects.equals(metadata, that.metadata)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  items,  kind,  metadata,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (items != null) { sb.append("items:"); sb.append(items + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata); }
    sb.append("}");
    return sb.toString();
  }
  class ItemsNestedImpl<N> extends ClusterServiceBrokerFluentImpl<ClusterServiceBrokerListFluentImpl.ItemsNested<N>> implements ClusterServiceBrokerListFluentImpl.ItemsNested<N>,Nested<N>{
    ItemsNestedImpl(int index,ClusterServiceBroker item) {
      this.index = index;
      this.builder = new ClusterServiceBrokerBuilder(this, item);
    }
    ItemsNestedImpl() {
      this.index = -1;
      this.builder = new ClusterServiceBrokerBuilder(this);
    }
    ClusterServiceBrokerBuilder builder;
    int index;
    public N and() {
      return (N) ClusterServiceBrokerListFluentImpl.this.setToItems(index,builder.build());
    }
    public N endItem() {
      return and();
    }
    
  }
  
}
